@@ -19,14 +19,15 @@
  * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301 USA
  */
 
-#if !defined (__COLORD_H_INSIDE__) && !defined (CD_COMPILATION)
-#error "Only <colord.h> can be included directly."
+#if !defined (__COLORD_GTK_H_INSIDE__) && !defined (CD_COMPILATION)
+#error "Only <colord-gtk.h> can be included directly."
 #endif
 
 #ifndef __CD_WINDOW_SYNC_H
 #define __CD_WINDOW_SYNC_H
 
 #include <glib-object.h>
+#include <gio/gio.h>
 
 G_BEGIN_DECLS
 
